Board.TiledBoard
======

**TiledBoard** is a child class of **Board**

```{eval-rst}
.. mermaid::

   classDiagram
      Board <|-- PixelBoard
      Board <|-- TiledBoard
      class Board{
      }
      class PixelBoard{

      }
      class TiledBoard{
      }  
```

## TiledBoard

```{eval-rst}
.. autoclass:: miniworldmaker.boards.tiled_board.TiledBoard
   :members:
```


